## $Id: pages.py 12956 2015-05-16 09:29:41Z henrik $
##
## Copyright (C) 2015 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
""" Viewing components for Kofa objects.
"""

from waeup.kofa.browser.pages import SourcesOverview
from kofacustom.nigeria.interfaces import (
    high_qual, high_grade, exam_types, LGASource)

class NigeriaSourcesOverview(SourcesOverview):


    def _set_high_qual(self):
        vocab_terms = high_qual.by_value.values()
        self.high_qual = sorted([(x.token, x.title,) for x in vocab_terms])
        return

    def _set_high_grade(self):
        vocab_terms = high_grade.by_value.values()
        self.high_grade = sorted([(x.token, x.title,) for x in vocab_terms])
        return

    def _set_exam_types(self):
        vocab_terms = exam_types.by_value.values()
        self.exam_types = sorted([(x.token, x.title,) for x in vocab_terms])
        return

    def _set_lgas(self):
        lgasource = LGASource().factory
        self.lgas = []
        for key in lgasource.getValues():
            title = lgasource.getTitle(key)
            self.lgas.append((key, title))
        return

    def update(self):
        super(NigeriaSourcesOverview, self).update()
        self._set_high_qual()
        self._set_high_grade()
        self._set_exam_types()
        self._set_lgas()
        return